==> gbsite-1.1.0.tar.gz: gbsite/templates/master/master_bugupdatepage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="2"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2">The following bug has <? if (empty($task_id)) { ?>not <? } ?>been assigned an owner.<? if($access_level=="4") { ?> You have access to update this bug's status below.<? } ?></font><br><br></td>
</tr>
<!-- Commented out Bug ID and Project Name as Id is unnecessary and project
  -- name is redundant
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Bug ID:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $bug_id ?></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Project Name:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $project_name ?></font></td>
</tr>
 -->
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Summary:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $title ?> 
<? if(!empty($task_id) && !empty($task_data)) { ?>
(assigned to task: <a href="/project/<?= $project_name ?>/task/taskshow.php?<?= $task_id ?>"><?= $task_data["task_name"] ?></a>)       
<? } ?>
</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Bug Type:</b></font></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2">
<?
    while(list($id,$name) = @each($class_list)) {
		 if ($id == $class_id) echo $name;
		}
?>
</font>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Severity:</b></font></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2">
<?
    while(list($id,$name) = @each($severity_list)) {
		 if ($id == $severity_id) echo $name;
		}
?>
</font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Software Version:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $version ?></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Environment:</b></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><blockquote><?= nl2br($environment) ?></blockquote></font></td>
</tr>
<!-- removed per ned's request 10.25.00 - jb
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>OS:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?=$os ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>OS Version:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $os_version ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Platform:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $platform ?></font></td>
</tr>
-->
<? if (!empty($created_by)) { ?>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Created By:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= getMemberName($created_by) ?></font></td>
</tr>
<? } else { ?>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Created By:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $email ?></font></td>
</tr>
<? } ?>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Description:</b></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><blockquote><?= nl2br($description) ?></blockquote></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Status:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $status_list[$status_id] ?></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Status Key:</b></font></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2"><i>
Submitted = Initial status of all bugs upon submission<br>
Assigned = A team member has been assigned to resolving this bug<br>
Open = The bug has been verified and will be fixed at some point<br>
Resolved = Solution found, not yet implemented<br>
Closed = The bug is fixed
</i></font>
</td>
</tr>
<!-- update bugs if admin -->
<? if($access_level=="4") { ?>
<form method="post" action="<?= $PHP_SELF ?>">
<input type="hidden" name="bug_update" value="yes">
<input type="hidden" name="bug_id" value="<?= $bug_id ?>">
<tr>
<td colspan="2"><hr width="80%" noshade></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Change Status:</b></font></td>
<td>
<select name="status_id">
<?
    while(list($id,$name) = @each($status_list)) {
		 $sel = ($id == $status_id ? "SELECTED" : "");
			echo "<option $sel value=$id>$name" ;
		}
?>
</select>	
&nbsp;<input type="submit" value="Change Status">
<br><font face="<?= $font_1 ?>" size="2"><i>This will change the status of any tasks associated with this bug.</i></font>
<br><br>
</td>
</tr>
</form>
<? if (empty($task_id)) { ?>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2">This bug has not been assigned an owner.<br><br>
You can <a href=/project/<?= $project_name ?>/task/taskadd.php?bug_id=<?= $bug_id ?>>click here to assign this bug</a>,
or select a task to attach this bug below:</font>
<form method="post" action=/project/<?= $project_name ?>/task/taskbug.php>
<input type="hidden" name="bug_id" value="<?= $bug_id ?>">

<select name="task_id">
    <? while(list($tid,$tname) = @each($task_list)) { 
           echo "<option value=" . $tid . ">" . $tname . "</option>";
       }
    ?>
</select>&nbsp;<input type="submit" value="go">
</form> 

</td>
</tr>
<? } else { ?>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2">This bug has been assigned an owner. <a href=/project/<?= $project_name ?>/task/taskshow.php?<?= $task_id ?>>Click here to update the task associated with it.</a></font></td>
</tr>
<? } ?>
<? } ?>
<!-- start the bug comments code -->
<tr><td colspan=2><hr width="80%" noshade></td></tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Bug Comments:</b></font></td>
<td align="right"><font face="<?= $font_1 ?>" size="2"><a href="#addcomment"><b>Add A Comment</b></a></font></td>
<? if(empty($bug_comments)) { ?>
<tr>
<td colspan="2" align="center"><font face="<?= $font_1 ?>" size="2">There are no comments for this bug at this time.</font></td>
</tr>
<? } else {
       while(list(,$comment) = @each($bug_comments)) { 
       if ($row_bgcolor == $color_2){
		$row_bgcolor = $color_7;
		}
		else {
		$row_bgcolor = $color_2; }
       ?>
<tr bgcolor="<?= $row_bgcolor ?>">
<td>&nbsp;</td>
<td><font face="<?= $font_1 ?>" size="2"><i><?= (empty($comment["created_by"])?$comment["email"]:getMemberName($comment["created_by"])) ?> : <?= date("m/d/Y",strtotime($comment["date_created"])) ?></i><br>
<blockquote><?= nl2br($comment["comment"]) ?></blockquote></font></td></tr>
<?     }
   } ?>
<tr>
<td colspan="2">&nbsp;<br><br></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><a name="addcomment"><b>Add a comment</b></a></font></td>
</tr>
<form method="post" action="/project/<?= $project_name ?>/bugs/bugcomment.php">
<input type="hidden" name="id" value="<?= $bug_id ?>">
<? if(empty($member_id)) { ?>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Email Address:</b></font></td>
<td><input type="text" name="email"></td>
</tr>
<? } ?>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Comment:</b></font></td>
<td><textarea name="comment" rows="5" cols="40" wrap></textarea></td>
</tr>
<tr>
<td>&nbsp;</td>
<td><input type="submit" value="Add Comment"></td>
</tr>
</form>
<!-- end the bug comments code -->
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_bugupdatepage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="2"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2">The following bug has <? if (empty($task_id)) { ?>not <? } ?>been assigned an owner.<? if($access_level=="4") { ?> You have access to update this bug's status below.<? } ?></font><br><br></td>
</tr>
<!-- Commented out Bug ID and Project Name as Id is unnecessary and project
  -- name is redundant
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Bug ID:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $bug_id ?></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Project Name:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $project_name ?></font></td>
</tr>
 -->
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Summary:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $title ?> 
<? if(!empty($task_id) && !empty($task_data)) { ?>
(assigned to task: <a href="/project/<?= $project_name ?>/task/taskshow.php?<?= $task_id ?>"><?= $task_data["task_name"] ?></a>)       
<? } ?>
</font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Bug Type:</b></font></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2">
<?
    while(list($id,$name) = @each($class_list)) {
		 if ($id == $class_id) echo $name;
		}
?>
</font>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Severity:</b></font></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2">
<?
    while(list($id,$name) = @each($severity_list)) {
		 if ($id == $severity_id) echo $name;
		}
?>
</font>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Software Version:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $version ?></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Environment:</b></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><blockquote><?= nl2br($environment) ?></blockquote></font></td>
</tr>
<!-- removed per ned's request 10.25.00 - jb
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>OS:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?=$os ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>OS Version:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $os_version ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Platform:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $platform ?></font></td>
</tr>
-->
<? if (!empty($created_by)) { ?>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Created By:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= getMemberName($created_by) ?></font></td>
</tr>
<? } else { ?>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Created By:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $email ?></font></td>
</tr>
<? } ?>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Description:</b></font></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><blockquote><?= nl2br($description) ?></blockquote></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Status:</b></font></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><?= $status_list[$status_id] ?></font></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Status Key:</b></font></td>
<td width="100%">
<font face="<?= $font_1 ?>" size="2"><i>
Submitted = Initial status of all bugs upon submission<br>
Assigned = A team member has been assigned to resolving this bug<br>
Open = The bug has been verified and will be fixed at some point<br>
Resolved = Solution found, not yet implemented<br>
Closed = The bug is fixed
</i></font>
</td>
</tr>
<!-- update bugs if admin -->
<? if($access_level=="4") { ?>
<form method="post" action="<?= $PHP_SELF ?>">
<input type="hidden" name="bug_update" value="yes">
<input type="hidden" name="bug_id" value="<?= $bug_id ?>">
<tr>
<td colspan="2"><hr width="80%" noshade></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Change Status:</b></font></td>
<td>
<select name="status_id">
<?
    while(list($id,$name) = @each($status_list)) {
		 $sel = ($id == $status_id ? "SELECTED" : "");
			echo "<option $sel value=$id>$name" ;
		}
?>
</select>	
&nbsp;<input type="submit" value="Change Status">
<br><font face="<?= $font_1 ?>" size="2"><i>This will change the status of any tasks associated with this bug.</i></font>
<br><br>
</td>
</tr>
</form>
<? if (empty($task_id)) { ?>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2">This bug has not been assigned an owner.<br><br>
You can <a href=/project/<?= $project_name ?>/task/taskadd.php?bug_id=<?= $bug_id ?>>click here to assign this bug</a>,
or select a task to attach this bug below:</font>
<form method="post" action=/project/<?= $project_name ?>/task/taskbug.php>
<input type="hidden" name="bug_id" value="<?= $bug_id ?>">

<select name="task_id">
    <? while(list($tid,$tname) = @each($task_list)) { 
           echo "<option value=" . $tid . ">" . $tname . "</option>";
       }
    ?>
</select>&nbsp;<input type="submit" value="go">
</form> 

</td>
</tr>
<? } else { ?>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2">This bug has been assigned an owner. <a href=/project/<?= $project_name ?>/task/taskshow.php?<?= $task_id ?>>Click here to update the task associated with it.</a></font></td>
</tr>
<? } ?>
<? } ?>
<!-- start the bug comments code -->
<tr><td colspan=2><hr width="80%" noshade></td></tr>
<tr>
<td><a name="#comments"><font face="<?= $font_1 ?>" size="2"><b>Bug Comments:</b></font></td>
<td align="right"><font face="<?= $font_1 ?>" size="2"><a href="#addcomment"><b>Add A Comment</b></a></font></td>
<? if(empty($bug_comments)) { ?>
<tr>
<td colspan="2" align="center"><font face="<?= $font_1 ?>" size="2">There are no comments for this bug at this time.</font></td>
</tr>
<? } else {
       while(list(,$comment) = @each($bug_comments)) { 
       if ($row_bgcolor == $color_2){
		$row_bgcolor = $color_7;
		}
		else {
		$row_bgcolor = $color_2; }
       ?>
<tr bgcolor="<?= $row_bgcolor ?>">
<td>&nbsp;</td>
<td><font face="<?= $font_1 ?>" size="2"><i><?= (empty($comment["created_by"])?$comment["email"]:getMemberName($comment["created_by"])) ?> : <?= date("m/d/Y",strtotime($comment["date_created"])) ?></i><br>
<blockquote><?= nl2br($comment["comment"]) ?></blockquote></font></td></tr>
<?     }
   } ?>
<tr>
<td colspan="2">&nbsp;<br><br></td>
</tr>
<tr>
<td colspan="2"><font face="<?= $font_1 ?>" size="2"><a name="addcomment"><b>Add a comment</b></a></font></td>
</tr>
<form method="post" action="/project/<?= $project_name ?>/bugs/bugcomment.php">
<input type="hidden" name="id" value="<?= $bug_id ?>">
<? if(empty($member_id)) { ?>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Email Address:</b></font></td>
<td><input type="text" name="email"></td>
</tr>
<? } ?>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Comment:</b></font></td>
<td><textarea name="comment" rows="5" cols="40" wrap></textarea></td>
</tr>
<tr>
<td>&nbsp;</td>
<td><input type="submit" value="Add Comment"></td>
</tr>
</form>
<!-- end the bug comments code -->
</table>
